import"./rolldown-runtime-DIIn1E2Q.js";import{O as e,R as t,Ut as n,et as r,j as i}from"./vendor-vue-core-DO0afONr.js";var a=``+new URL(`images/cloud-subscription.webm`,import.meta.url).href,o={class:`flex flex-col items-start gap-0 self-stretch`},s={class:`flex items-center gap-2 py-2`},c={class:`text-sm text-text-primary`},l={class:`flex items-center gap-2 py-2`},u={class:`text-sm text-text-primary`},d={class:`flex items-center gap-2 py-2`},f={class:`text-sm text-text-primary`},p=t({__name:`SubscriptionBenefits`,props:{isFreeTier:{type:Boolean,default:!1}},setup(t){return(t,a)=>(r(),i(`div`,o,[e(`div`,s,[a[0]||=e(`i`,{class:`pi pi-check text-xs text-text-primary`},null,-1),e(`span`,c,n(t.isFreeTier?t.$t(`subscription.benefits.benefit1FreeTier`):t.$t(`subscription.benefits.benefit1`)),1)]),e(`div`,l,[a[1]||=e(`i`,{class:`pi pi-check text-xs text-text-primary`},null,-1),e(`span`,u,n(t.$t(`subscription.benefits.benefit2`)),1)]),e(`div`,d,[a[2]||=e(`i`,{class:`pi pi-check text-xs text-text-primary`},null,-1),e(`span`,f,n(t.$t(`subscription.benefits.benefit3`)),1)])]))}});export{a as n,p as t};
//# sourceMappingURL=SubscriptionBenefits-BQfX-Lju.js.map