import"./rolldown-runtime-DIIn1E2Q.js";import{Bt as e,O as t,R as n,Rt as r,Z as i,et as a,j as o,kt as s,q as c,rt as l,v as u,vt as d}from"./vendor-vue-core-DO0afONr.js";import{n as f}from"./types-DPJvCrdo.js";import{n as p,t as m}from"./envUtil-BPtcYFTX.js";var h={class:`flex w-full grow items-center justify-center overflow-auto`},g=n({__name:`BaseViewTemplate`,props:{dark:{type:Boolean,default:!1}},setup(n){let g={color:`rgba(0, 0, 0, 0)`,symbolColor:`#d4d4d4`},_={color:`rgba(0, 0, 0, 0)`,symbolColor:`#171717`},v=s(null);return i(async()=>{f&&(await c(),m().changeTheme({...n.dark?g:_,height:v.value?.getBoundingClientRect().height??0}))}),(n,i)=>(a(),o(`div`,{class:e([`flex h-svh w-screen flex-col font-sans`,[n.dark?`dark-theme bg-neutral-900 text-neutral-300`:`bg-neutral-300 text-neutral-900`]])},[d(t(`div`,{ref_key:`topMenuRef`,ref:v,class:`app-drag h-(--comfy-topbar-height) w-full`},null,512),[[u,r(p)()]]),t(`div`,h,[l(n.$slots,`default`)])],2))}});export{g as t};
//# sourceMappingURL=BaseViewTemplate-DBZUwRdb.js.map