import"./rolldown-runtime-DIIn1E2Q.js";var e=[`style`,`class`,`dt`,`pt`,`ptOptions`,`unstyled`],t=[...e,`inputClass`,`inputStyle`,`read_only`],n=[...e,`panelClass`,`panelStyle`,`overlayClass`],r=[...e,`thumbnailsPosition`,`verticalThumbnailViewPortHeight`,`indicatorsPosition`,`maskClass`,`containerStyle`,`containerClass`,`galleriaClass`],i=[...e,`badgeClass`];function filterWidgetProps(e,t){if(!e)return{};let n={};for(let[r,i]of Object.entries(e))t.includes(r)||(n[r]=i);return n}export{e as a,n as i,r as n,filterWidgetProps as o,t as r,i as t};
//# sourceMappingURL=widgetPropFilter-CM0eri-7.js.map