import"./rolldown-runtime-DIIn1E2Q.js";import"./vendor-primevue-_eYbXsHY.js";import"./vendor-firebase-D7u00oy9.js";import{D as e,pt as t}from"./vendor-vue-core-DO0afONr.js";import"./vendor-other-D7fTIduy.js";import{i as n}from"./useFeatureFlags-ChmiVSwD.js";import"./api-BebQfoGK.js";import"./vendor-markdown-Da9QPS2x.js";import"./colorUtil-xHrUTSza.js";import{o as r}from"./i18n-dAUEhQVe.js";import"./vendor-reka-ui-D1HCh14_.js";import"./Button-hTbieW3T.js";import{ar as i,b as a}from"./dialogService-Cm1GEBK8.js";import"./formatUtil-Gr6H7233.js";import"./userStore-DMlTsx5E.js";import"./useErrorHandling-DudkVSep.js";import"./extensionStore-P-YqST__.js";import"./useExternalLink-DY6FqhTr.js";import"./vendor-tiptap-CcjHVRxb.js";import"./markdownRendererUtil-PltcX2Bi.js";import"./Popover-BhkpNQxC.js";import"./electronDownloadStore-BYrGQ7mS.js";var o=e(()=>{let e=[],t=n.value.server_health_alert;return t&&e.push({text:t.message,label:t.badge,variant:t.severity??`error`,tooltip:t.tooltip}),e}),s=a();t(()=>s.canvas,e=>{e&&(e.info_text=r(`g.comfyCloud`))},{immediate:!0}),i().registerExtension({name:`Comfy.Cloud.Badges`,get topbarBadges(){return o.value}});
//# sourceMappingURL=cloudBadges-BZSP-97Z.js.map