import"./rolldown-runtime-DIIn1E2Q.js";import{D as e,O as t,R as n,Ut as r,et as i,j as a,kt as o}from"./vendor-vue-core-DO0afONr.js";var s={class:`relative size-full overflow-hidden rounded-sm`},c=[`src`,`alt`],l={key:1,class:`flex size-full flex-col items-center justify-center gap-2 bg-modal-card-placeholder-background transition-transform duration-300 group-hover:scale-105 group-data-[selected=true]:scale-105`},u={class:`text-sm text-base-foreground`},d=n({__name:`Media3DTop`,props:{asset:{}},setup(n){let d=o(!1),f=e(()=>n.asset?.src?n.asset.src.replace(/([?&]filename=)([^&]*)/,`$1$2.png`):``);return(e,n)=>(i(),a(`div`,s,[d.value?(i(),a(`div`,l,[n[1]||=t(`i`,{class:`icon-[lucide--box] text-3xl text-muted-foreground`},null,-1),t(`span`,u,r(e.$t(`assetBrowser.media.threeDModelPlaceholder`)),1)])):(i(),a(`img`,{key:0,src:f.value,alt:e.asset?.name,class:`size-full object-contain transition-transform duration-300 group-hover:scale-105 group-data-[selected=true]:scale-105`,onError:n[0]||=e=>d.value=!0},null,40,c))]))}});export{d as default};
//# sourceMappingURL=Media3DTop-DavyUdCQ.js.map