import"./rolldown-runtime-DIIn1E2Q.js";import{i as e,n as t}from"./vendor-primevue-_eYbXsHY.js";import"./vendor-firebase-D7u00oy9.js";import{F as n,I as r,R as i,Rt as a,Ut as o,_t as s,et as c,k as l,kt as u}from"./vendor-vue-core-DO0afONr.js";import"./vendor-other-D7fTIduy.js";import"./useFeatureFlags-ChmiVSwD.js";import"./api-BebQfoGK.js";import"./vendor-markdown-Da9QPS2x.js";import"./colorUtil-xHrUTSza.js";import"./i18n-dAUEhQVe.js";import"./vendor-reka-ui-D1HCh14_.js";import{t as d}from"./Button-hTbieW3T.js";import{xi as f}from"./dialogService-Cm1GEBK8.js";import"./formatUtil-Gr6H7233.js";import"./userStore-DMlTsx5E.js";import"./useErrorHandling-DudkVSep.js";import"./extensionStore-P-YqST__.js";import"./useExternalLink-DY6FqhTr.js";import"./vendor-tiptap-CcjHVRxb.js";import"./markdownRendererUtil-PltcX2Bi.js";import"./Popover-BhkpNQxC.js";import"./electronDownloadStore-BYrGQ7mS.js";import{i as p}from"./signInSchema-HMvr_R4g.js";import{t as m}from"./PasswordFields-CZJEU0zr.js";var h=i({__name:`UpdatePasswordContent`,props:{onSuccess:{type:Function}},setup(i){let h=f(),g=u(!1),onSubmit=async e=>{if(e.valid){g.value=!0;try{await h.updatePassword(e.values.password),i.onSuccess()}finally{g.value=!1}}};return(i,u)=>(c(),l(a(e),{class:`flex w-96 flex-col gap-6`,resolver:a(t)(a(p)),onSubmit},{default:s(()=>[r(m),r(d,{type:`submit`,class:`mt-4 h-10 font-medium`,loading:g.value},{default:s(()=>[n(o(i.$t(`userSettings.updatePassword`)),1)]),_:1},8,[`loading`])]),_:1},8,[`resolver`]))}});export{h as default};
//# sourceMappingURL=UpdatePasswordContent-DQJieamI.js.map