import"./rolldown-runtime-DIIn1E2Q.js";import{Bt as e,O as t,R as n,Rt as r,Ut as i,et as a,j as o}from"./vendor-vue-core-DO0afONr.js";import{n as s}from"./vendor-i18n-JbyM4Qz7.js";import{t as c}from"./src-D_KFn0Xz.js";var l={role:`status`,class:`inline-flex`},u={class:`sr-only`},d=n({__name:`Loader`,props:{size:{}},setup(n){let{t:d}=s(),f=n.size?{sm:`size-4`,md:`size-8`,lg:`size-12`}[n.size]:``;return(n,s)=>(a(),o(`span`,l,[t(`i`,{"aria-hidden":`true`,class:e(r(c)(`icon-[lucide--loader-circle] animate-spin`,r(f)))},null,2),t(`span`,u,i(r(d)(`g.loading`)),1)]))}});export{d as t};
//# sourceMappingURL=Loader-tgMSU-yO.js.map