import"./vendor-other-D7fTIduy.js";import"./vendor-markdown-Da9QPS2x.js";import"./formatUtil-Gr6H7233.js";import"./electronDownloadStore-BYrGQ7mS.js";import{n as e}from"./missingModelDownload-D0yUaI3m.js";export{e as fetchModelMetadata};