const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=["./i18n-DLnLx1VJ.js","./vendor-primevue-_eYbXsHY.js","./rolldown-runtime-DIIn1E2Q.js","./vendor-vue-core-DO0afONr.js","./i18n-dAUEhQVe.js","./vendor-i18n-JbyM4Qz7.js"])))=>i.map(i=>d[i]);
import"./rolldown-runtime-DIIn1E2Q.js";import{ct as e}from"./vendor-primevue-_eYbXsHY.js";import{c as t,l as n}from"./vendor-vue-core-DO0afONr.js";import{t as r}from"./types-DPJvCrdo.js";import{Y as i,c as a}from"./vendor-vueuse-DUMtJaL2.js";import{r as o}from"./api-BebQfoGK.js";import{i as s,ji as c,w as l}from"./dialogService-Cm1GEBK8.js";import{t as u}from"./userStore-DMlTsx5E.js";var d=t(`bootstrap`,()=>{let t=s(),d=l(),{isReady:f,error:p,execute:m}=a(async()=>{let{mergeCustomNodesI18n:t}=await e(async()=>{let{mergeCustomNodesI18n:e}=await import(`./i18n-DLnLx1VJ.js`);return{mergeCustomNodesI18n:e}},__vite__mapDeps([0,1,2,3,4,5]),import.meta.url);t(await o.getCustomNodesI18n())},void 0,{immediate:!1}),h=!1;function loadAuthenticatedStores(){h||(h=!0,t.load(),d.loadWorkflows())}async function startStoreBootstrap(){let e=u();if(await e.initialize(),r){let{isInitialized:e}=n(c());await i(e).toBe(!0)}let{needsLogin:t}=n(e);await i(t).toBe(!1),m(),loadAuthenticatedStores()}return{isI18nReady:f,i18nError:p,startStoreBootstrap}});export{d as t};
//# sourceMappingURL=bootstrapStore-DbIZpeqf.js.map