[data-v-df290087] .p-terminal .xterm{overflow:hidden}[data-v-df290087] .p-terminal .xterm-screen{background-color:var(--color-neutral-900);overflow:hidden}[data-v-a37adc34] .p-terminal .xterm{overflow-x:auto}[data-v-a37adc34] .p-terminal .xterm-screen{overflow-y:hidden}[data-v-49782f06] .p-terminal .xterm{overflow-x:auto}[data-v-49782f06] .p-terminal .xterm-screen{overflow-y:hidden}
