import"./rolldown-runtime-DIIn1E2Q.js";import{U as e}from"./vendor-vue-core-DO0afONr.js";var t=Symbol(),n=Symbol();function useHideLayoutField(){return e(n,!1)}export{t as n,useHideLayoutField as r,n as t};
//# sourceMappingURL=widgetTypes-C2VkGR_p.js.map