import"./vendor-primevue-_eYbXsHY.js";import"./vendor-other-D7fTIduy.js";import"./api-BebQfoGK.js";import"./vendor-markdown-Da9QPS2x.js";import"./colorUtil-xHrUTSza.js";import"./i18n-dAUEhQVe.js";import{t as e}from"./auth-C9CODXOk.js";export{e as getSurveyCompletedStatus};