import"./rolldown-runtime-DIIn1E2Q.js";import{P as e}from"./vendor-primevue-_eYbXsHY.js";import{D as t,R as n,Rt as r,et as i,k as a,kt as o}from"./vendor-vue-core-DO0afONr.js";var s=n({__name:`UserAvatar`,props:{photoUrl:{},ariaLabel:{}},setup(n){let s=o(!1),handleImageError=()=>{s.value=!0},c=t(()=>n.photoUrl&&!s.value);return(t,n)=>(i(),a(r(e),{class:`aspect-square bg-interface-panel-selected-surface`,image:t.photoUrl??void 0,icon:c.value?void 0:`icon-[lucide--user]`,"pt:icon:class":{"size-4":!c.value},shape:`circle`,"aria-label":t.ariaLabel??t.$t(`auth.login.userAvatar`),onError:handleImageError},null,8,[`image`,`icon`,`pt:icon:class`,`aria-label`]))}});export{s as t};
//# sourceMappingURL=UserAvatar-Dm1rTHqa.js.map