import"./rolldown-runtime-DIIn1E2Q.js";import{t as e}from"./vendor-primevue-_eYbXsHY.js";import{D as t,G as n,I as r,O as i,R as a,Rt as o,et as s,j as c,ut as l}from"./vendor-vue-core-DO0afONr.js";var u={class:`flex flex-col gap-1`},d={class:`max-h-192 rounded-sm border p-4`},f=a({__name:`WidgetChart`,props:n({widget:{}},{modelValue:{required:!0},modelModifiers:{}}),emits:[`update:modelValue`],setup(n){let a=l(n,`modelValue`),f=n,p=t(()=>f.widget.options?.type??`line`),m=t(()=>a.value||{labels:[],datasets:[]}),h=t(()=>({responsive:!0,maintainAspectRatio:!1,plugins:{legend:{labels:{color:`#FFF`,usePointStyle:!0,pointStyle:`circle`}}},scales:{x:{ticks:{color:`#9FA2BD`},grid:{display:!0,color:`#9FA2BD`,drawTicks:!1,drawOnChartArea:!0,drawBorder:!1},border:{display:!0,color:`#9FA2BD`}},y:{ticks:{color:`#9FA2BD`},grid:{display:!1,drawTicks:!1,drawOnChartArea:!1,drawBorder:!1},border:{display:!0,color:`#9FA2BD`}}}}));return(t,n)=>(s(),c(`div`,u,[i(`div`,d,[r(o(e),{type:p.value,data:m.value,options:h.value,"aria-label":`${t.widget.name||t.$t(`g.chart`)} - ${p.value} ${t.$t(`g.chartLowercase`)}`},null,8,[`type`,`data`,`options`,`aria-label`])])]))}});export{f as default};
//# sourceMappingURL=WidgetChart-BfKMPNmx.js.map