import"./rolldown-runtime-DIIn1E2Q.js";import{A as e,Bt as t,R as n,Rt as r,_t as i,et as a,j as o,k as s,rt as c}from"./vendor-vue-core-DO0afONr.js";import{O as l}from"./vendor-other-D7fTIduy.js";import{vt as u}from"./vendor-reka-ui-D1HCh14_.js";import{t as d}from"./src-D_KFn0Xz.js";var f=l({base:`relative inline-flex items-center justify-center gap-2 cursor-pointer touch-manipulation whitespace-nowrap appearance-none border-none rounded-md text-sm font-medium font-inter transition-colors focus-visible:outline-none focus-visible:ring-1 focus-visible:ring-ring disabled:pointer-events-none disabled:opacity-50 [&_svg]:pointer-events-none [&_svg:not([width]):not([height])]:size-4 [&_svg]:shrink-0`,variants:{variant:{secondary:`text-secondary-foreground bg-secondary-background hover:bg-secondary-background-hover`,primary:`bg-primary-background text-base-foreground hover:bg-primary-background-hover`,inverted:`bg-base-foreground text-base-background hover:bg-base-foreground/80`,destructive:`bg-destructive-background text-base-foreground hover:bg-destructive-background-hover`,textonly:`bg-transparent text-base-foreground hover:bg-secondary-background-hover`,"muted-textonly":`bg-transparent text-muted-foreground hover:bg-secondary-background-hover`,"destructive-textonly":`bg-transparent text-destructive-background hover:bg-destructive-background/10`,"overlay-white":`bg-white text-gray-600 hover:bg-white/90`,base:`bg-base-background text-base-foreground hover:bg-secondary-background-hover`,gradient:`border-transparent bg-(image:--subscription-button-gradient) text-white hover:opacity-90`},size:{sm:`h-6 rounded-sm px-2 py-1 text-xs`,md:`h-8 rounded-lg p-2 text-xs`,lg:`h-10 rounded-lg px-4 py-2 text-sm`,icon:`size-8`,"icon-sm":`size-5 p-0`,unset:``}},defaultVariants:{variant:`secondary`,size:`md`}}),p={key:0,class:`pi pi-spin pi-spinner`},m=n({__name:`Button`,props:{variant:{},size:{},class:{default:``},loading:{type:Boolean,default:!1},disabled:{type:Boolean,default:!1},asChild:{type:Boolean},as:{default:`button`}},setup(n){return(l,m)=>(a(),s(r(u),{as:l.as,"as-child":l.asChild,disabled:l.disabled||l.loading,class:t(r(d)(r(f)({variant:l.variant,size:l.size}),n.class))},{default:i(()=>[l.loading?(a(),o(`i`,p)):e(``,!0),l.loading?e(``,!0):c(l.$slots,`default`,{key:1})]),_:3},8,[`as`,`as-child`,`disabled`,`class`]))}});export{m as t};
//# sourceMappingURL=Button-hTbieW3T.js.map