const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=["./CloudLayoutView-DI3qJ-FI.js","./_plugin-vue_export-helper-C-lmfiIY.js","./rolldown-runtime-DIIn1E2Q.js","./vendor-primevue-_eYbXsHY.js","./vendor-vue-core-DO0afONr.js","./dialogService-Cm1GEBK8.js","./vendor-other-D7fTIduy.js","./vendor-firebase-D7u00oy9.js","./vendor-three-8NczM_fZ.js","./vendor-tiptap-CcjHVRxb.js","./vendor-reka-ui-D1HCh14_.js","./vendor-i18n-JbyM4Qz7.js","./vendor-sentry-DFQqneKv.js","./vendor-vueuse-DUMtJaL2.js","./vendor-axios-B2OLCPxZ.js","./vendor-markdown-Da9QPS2x.js","./vendor-zod-AyupqgYk.js","./formatUtil-Gr6H7233.js","./src-D_KFn0Xz.js","./Loader-tgMSU-yO.js","./Popover-BhkpNQxC.js","./Button-hTbieW3T.js","./SelectValue-C3IEVAMi.js","./extensionStore-P-YqST__.js","./api-BebQfoGK.js","./vendor-yjs-BsN9BCzH.js","./i18n-dAUEhQVe.js","./widget-BH5tDli6.js","./types-DPJvCrdo.js","./colorUtil-xHrUTSza.js","./useErrorHandling-DudkVSep.js","./useExternalLink-DY6FqhTr.js","./envUtil-BPtcYFTX.js","./useFeatureFlags-ChmiVSwD.js","./VideoPlayOverlay-DAgHndSD.js","./assetMetadataUtils-Bi25nHoy.js","./telemetry-B-mZAUOK.js","./electronDownloadStore-BYrGQ7mS.js","./userStore-DMlTsx5E.js","./widgetTypes-C2VkGR_p.js","./markdownRendererUtil-PltcX2Bi.js","./GlobalToast-DHYvVkn4.js","./BaseViewTemplate-DBZUwRdb.js","./vendor-other-CaaUC6Qe.css","./dialogService-BLSXtWly.css","./CloudLayoutView-C-gB3SQs.css","./CloudLoginView-DwM0bgPI.js","./previousFullPath-Qv8zLBVO.js","./signInSchema-HMvr_R4g.js","./CloudLoginView-BNhCiCVb.css","./useCurrentUser-C_hX8m5r.js","./CloudSignupView-qCuKmLN3.js","./PasswordFields-CZJEU0zr.js","./SignUpForm-CqssIAqp.js","./CloudSignupView-C0QtxnNH.css","./CloudForgotPasswordView-ChLAbPcR.js","./CloudForgotPasswordView-CPI_0LyH.css","./CloudSurveyView-CNc7eTIu.js","./auth-C9CODXOk.js","./CloudSurveyView-BS7kjG6B.css","./UserCheckView-DaQZIZ67.js","./CloudSorryContactSupportView-BWNx9mTe.js","./CloudSorryContactSupportView-cvR6d1qS.css","./CloudAuthTimeoutView-D03_zBjg.js","./CloudSubscriptionRedirectView-FyjhMqeR.js","./comfy-logo-single-CTKe8r7z.js","./subscriptionCheckoutUtil-cpmmH4Fl.js"])))=>i.map(i=>d[i]);
import"./rolldown-runtime-DIIn1E2Q.js";import{ct as e}from"./vendor-primevue-_eYbXsHY.js";var t=[{path:`/cloud`,component:()=>e(()=>import(`./CloudLayoutView-DI3qJ-FI.js`),__vite__mapDeps([0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45]),import.meta.url),children:[{path:`login`,name:`cloud-login`,component:()=>e(()=>import(`./CloudLoginView-DwM0bgPI.js`),__vite__mapDeps([46,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,47,48,43,44,49]),import.meta.url),beforeEnter:async(t,n,r)=>{if(!t.query.switchAccount){let{useCurrentUser:t}=await e(async()=>{let{useCurrentUser:e}=await import(`./useCurrentUser-C_hX8m5r.js`);return{useCurrentUser:e}},__vite__mapDeps([50,3,2,4,5,1,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,43,44]),import.meta.url),{isLoggedIn:n}=t();if(n.value)return r({name:`cloud-user-check`})}r()}},{path:`signup`,name:`cloud-signup`,component:()=>e(()=>import(`./CloudSignupView-qCuKmLN3.js`),__vite__mapDeps([51,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,52,53,48,47,43,44,54]),import.meta.url),beforeEnter:async(t,n,r)=>{if(!t.query.switchAccount){let{useCurrentUser:t}=await e(async()=>{let{useCurrentUser:e}=await import(`./useCurrentUser-C_hX8m5r.js`);return{useCurrentUser:e}},__vite__mapDeps([50,3,2,4,5,1,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,43,44]),import.meta.url),{isLoggedIn:n}=t();if(n.value)return r({name:`cloud-user-check`})}r()}},{path:`forgot-password`,name:`cloud-forgot-password`,component:()=>e(()=>import(`./CloudForgotPasswordView-ChLAbPcR.js`),__vite__mapDeps([55,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,43,44,56]),import.meta.url)},{path:`survey`,name:`cloud-survey`,component:()=>e(()=>import(`./CloudSurveyView-CNc7eTIu.js`),__vite__mapDeps([57,1,2,3,4,6,7,8,9,10,11,15,21,18,33,24,13,14,25,16,26,27,28,29,58,12,36,43,59]),import.meta.url),meta:{requiresAuth:!0}},{path:`user-check`,name:`cloud-user-check`,component:()=>e(()=>import(`./UserCheckView-DaQZIZ67.js`),__vite__mapDeps([60,2,3,4,6,7,8,9,10,13,15,21,18,30,24,14,25,16,26,11,27,28,29,33,58,12,43]),import.meta.url),meta:{requiresAuth:!0}},{path:`sorry-contact-support`,name:`cloud-sorry-contact-support`,component:()=>e(()=>import(`./CloudSorryContactSupportView-BWNx9mTe.js`),__vite__mapDeps([61,1,2,11,4,62]),import.meta.url)},{path:`auth-timeout`,name:`cloud-auth-timeout`,component:()=>e(()=>import(`./CloudAuthTimeoutView-D03_zBjg.js`),__vite__mapDeps([63,2,3,4,5,1,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,43,44]),import.meta.url),props:!0},{path:`subscribe`,name:`cloud-subscribe`,component:()=>e(()=>import(`./CloudSubscriptionRedirectView-FyjhMqeR.js`),__vite__mapDeps([64,2,3,4,5,1,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,65,66,43,44]),import.meta.url),meta:{requiresAuth:!0}}]}];export{t as cloudOnboardingRoutes};
//# sourceMappingURL=onboardingCloudRoutes-BD-sPNcZ.js.map