import"./rolldown-runtime-DIIn1E2Q.js";import{A as e,Bt as t,D as n,F as r,O as i,R as a,Rt as o,S as s,Ut as c,b as l,et as u,j as d,rt as f}from"./vendor-vue-core-DO0afONr.js";import{t as p}from"./src-D_KFn0Xz.js";import{r as m}from"./widgetTypes-C2VkGR_p.js";var h={key:0,class:`content-center-safe truncate`},g={class:`relative min-w-0 flex-1`},_=a({__name:`WidgetLayoutField`,props:{widget:{},rootClass:{},noBorder:{type:Boolean}},setup(a){let _=m(),v=n(()=>p(`focus-within:ring focus-within:ring-component-node-widget-background-highlighted`,a.widget.borderStyle));return(n,a)=>(u(),d(`div`,{class:t(o(p)(`grid min-w-0 grid-cols-subgrid justify-between gap-1 text-node-component-slot-text`,n.rootClass))},[o(_)?e(``,!0):(u(),d(`div`,h,[n.widget.name?(u(),d(s,{key:0},[r(c(n.widget.label||n.widget.name),1)],64)):e(``,!0)])),i(`div`,g,[i(`div`,{class:t(o(p)(`min-w-0 cursor-default rounded-lg transition-all`,!n.noBorder&&v.value)),onPointerdown:a[0]||=l(()=>{},[`stop`]),onPointermove:a[1]||=l(()=>{},[`stop`]),onPointerup:a[2]||=l(()=>{},[`stop`])},[f(n.$slots,`default`,{borderStyle:v.value})],34)])],2))}});export{_ as t};
//# sourceMappingURL=WidgetLayoutField-CJulDjD5.js.map