import"./rolldown-runtime-DIIn1E2Q.js";import"./vendor-primevue-_eYbXsHY.js";import"./vendor-firebase-D7u00oy9.js";import{A as e,Bt as t,F as n,I as r,O as i,R as a,S as o,Ut as s,_t as c,et as l,j as u,kt as d,nt as f,o as p}from"./vendor-vue-core-DO0afONr.js";import"./vendor-other-D7fTIduy.js";import"./useFeatureFlags-ChmiVSwD.js";import"./api-BebQfoGK.js";import"./vendor-markdown-Da9QPS2x.js";import"./colorUtil-xHrUTSza.js";import"./i18n-dAUEhQVe.js";import"./vendor-reka-ui-D1HCh14_.js";import{t as m}from"./Button-hTbieW3T.js";import{xi as h}from"./dialogService-Cm1GEBK8.js";import"./formatUtil-Gr6H7233.js";import"./userStore-DMlTsx5E.js";import"./useErrorHandling-DudkVSep.js";import"./extensionStore-P-YqST__.js";import"./useExternalLink-DY6FqhTr.js";import"./vendor-tiptap-CcjHVRxb.js";import"./markdownRendererUtil-PltcX2Bi.js";import"./Popover-BhkpNQxC.js";import"./electronDownloadStore-BYrGQ7mS.js";var g={class:`flex h-full items-center justify-center p-6`},_={class:`max-w-[100vw] text-center lg:w-[500px]`},v={class:`mb-3 text-xl text-text-primary`},y={class:`mb-5 text-muted`},b={class:`mb-4 rounded-sm bg-secondary-background px-3 py-2 text-left`},x={class:`mb-2 text-sm font-semibold text-text-primary`},S={class:`space-y-1.5 text-sm text-muted`},C={key:0,class:`mb-4 text-left`},w={key:0,class:`mt-2 rounded-sm border border-muted-background p-4 font-mono text-xs break-all text-muted-foreground`},T={class:`mb-5 text-center text-sm text-gray-600`},E={href:`https://support.comfy.org`,class:`cursor-pointer text-blue-400 no-underline`,target:`_blank`,rel:`noopener noreferrer`},D={class:`flex flex-col gap-3`},O=a({__name:`CloudAuthTimeoutView`,props:{errorMessage:{}},setup(a){let O=p(),{logout:k}=h(),A=d(!1),handleRestart=async()=>{await k(),await O.replace({name:`cloud-login`})};return(a,d)=>(l(),u(`div`,g,[i(`div`,_,[i(`h2`,v,s(a.$t(`cloudOnboarding.authTimeout.title`)),1),i(`p`,y,s(a.$t(`cloudOnboarding.authTimeout.message`)),1),i(`div`,b,[i(`h3`,x,s(a.$t(`cloudOnboarding.authTimeout.troubleshooting`)),1),i(`ul`,S,[(l(!0),u(o,null,f(a.$tm(`cloudOnboarding.authTimeout.causes`),(e,t)=>(l(),u(`li`,{key:t,class:`flex gap-2`},[d[1]||=i(`span`,null,`•`,-1),i(`span`,null,s(e),1)]))),128))])]),a.errorMessage?(l(),u(`div`,C,[i(`button`,{class:`flex w-full items-center justify-between rounded-sm border-0 bg-secondary-background px-4 py-2 text-sm text-text-secondary transition-colors hover:bg-secondary-background-hover`,onClick:d[0]||=e=>A.value=!A.value},[i(`span`,null,s(a.$t(`cloudOnboarding.authTimeout.technicalDetails`)),1),i(`i`,{class:t([`pi`,A.value?`pi-chevron-up`:`pi-chevron-down`])},null,2)]),A.value?(l(),u(`div`,w,s(a.errorMessage),1)):e(``,!0)])):e(``,!0),i(`p`,T,[n(s(a.$t(`cloudOnboarding.authTimeout.helpText`))+` `,1),i(`a`,E,s(a.$t(`cloudOnboarding.authTimeout.supportLink`)),1),d[2]||=n(`. `)]),i(`div`,D,[r(m,{class:`w-full`,onClick:handleRestart},{default:c(()=>[n(s(a.$t(`cloudOnboarding.authTimeout.restart`)),1)]),_:1})])])]))}});export{O as default};
//# sourceMappingURL=CloudAuthTimeoutView-D03_zBjg.js.map