import"./rolldown-runtime-DIIn1E2Q.js";import{D as e}from"./vendor-vue-core-DO0afONr.js";import{n as t}from"./types-DPJvCrdo.js";import{n}from"./i18n-dAUEhQVe.js";import{t as r}from"./envUtil-BPtcYFTX.js";function useExternalLink(){let i=e(()=>String(n.global.locale.value)),a=e(()=>i.value===`zh`||i.value===`zh-TW`),o=e(()=>t?r().getPlatform()===`darwin`?`macos`:`windows`:null),buildDocsUrl=(e,t={})=>{let{includeLocale:n=!1,platform:r=!1}=t,i=`https://docs.comfy.org`;n&&a.value&&(i+=`/zh-CN`);let s=e.startsWith(`/`)?e:`/${e}`;return i+=s,r&&o.value&&(i=i.endsWith(`/`)?i:`${i}/`,i+=o.value),i};return{buildDocsUrl,staticUrls:{discord:`https://www.comfy.org/discord`,github:`https://github.com/comfyanonymous/ComfyUI`,githubIssues:`https://github.com/comfyanonymous/ComfyUI/issues`,githubFrontend:`https://github.com/Comfy-Org/ComfyUI_frontend`,githubElectron:`https://github.com/Comfy-Org/electron`,forum:`https://forum.comfy.org/`,comfyOrg:`https://www.comfy.org/`},docsPaths:{partnerNodesPricing:`/tutorials/partner-nodes/pricing`}}}export{useExternalLink as t};
//# sourceMappingURL=useExternalLink-DY6FqhTr.js.map