const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=["./ValueControlPopover-B4ZTqZ2U.js","./rolldown-runtime-DIIn1E2Q.js","./vendor-primevue-_eYbXsHY.js","./vendor-vue-core-DO0afONr.js","./dialogService-Cm1GEBK8.js","./_plugin-vue_export-helper-C-lmfiIY.js","./vendor-other-D7fTIduy.js","./vendor-firebase-D7u00oy9.js","./vendor-three-8NczM_fZ.js","./vendor-tiptap-CcjHVRxb.js","./vendor-reka-ui-D1HCh14_.js","./vendor-i18n-JbyM4Qz7.js","./vendor-sentry-DFQqneKv.js","./vendor-vueuse-DUMtJaL2.js","./vendor-axios-B2OLCPxZ.js","./vendor-markdown-Da9QPS2x.js","./vendor-zod-AyupqgYk.js","./formatUtil-Gr6H7233.js","./src-D_KFn0Xz.js","./Loader-tgMSU-yO.js","./Popover-BhkpNQxC.js","./Button-hTbieW3T.js","./SelectValue-C3IEVAMi.js","./extensionStore-P-YqST__.js","./api-BebQfoGK.js","./vendor-yjs-BsN9BCzH.js","./i18n-dAUEhQVe.js","./widget-BH5tDli6.js","./types-DPJvCrdo.js","./colorUtil-xHrUTSza.js","./useErrorHandling-DudkVSep.js","./useExternalLink-DY6FqhTr.js","./envUtil-BPtcYFTX.js","./useFeatureFlags-ChmiVSwD.js","./VideoPlayOverlay-DAgHndSD.js","./assetMetadataUtils-Bi25nHoy.js","./telemetry-B-mZAUOK.js","./electronDownloadStore-BYrGQ7mS.js","./userStore-DMlTsx5E.js","./widgetTypes-C2VkGR_p.js","./markdownRendererUtil-PltcX2Bi.js","./vendor-other-CaaUC6Qe.css","./dialogService-BLSXtWly.css"])))=>i.map(i=>d[i]);
import"./rolldown-runtime-DIIn1E2Q.js";import{ct as e}from"./vendor-primevue-_eYbXsHY.js";import{A as t,Bt as n,G as r,I as i,K as a,L as o,R as s,Rt as c,Ut as l,_t as u,et as d,j as f,k as p,kt as m,ot as h,pt as g,ut as _}from"./vendor-vue-core-DO0afONr.js";import{n as v}from"./vendor-i18n-JbyM4Qz7.js";import{t as y}from"./src-D_KFn0Xz.js";import{t as b}from"./Popover-BhkpNQxC.js";var x=[`aria-label`],S={key:1,class:`text-xs font-normal text-primary-background`},C=s({__name:`ValueControlButton`,props:{mode:{},variant:{default:`badge`}},setup(e){let{t:r}=v(),i={fixed:`icon-[lucide--pencil-off]`,randomize:`icon-[lucide--shuffle]`,increment:null,decrement:null},a={increment:`+1`,decrement:`-1`,fixed:null,randomize:null};return(e,o)=>(d(),f(`button`,{type:`button`,"aria-label":c(r)(`widgets.valueControl.`+e.mode),class:n(c(y)(`flex shrink-0 cursor-pointer items-center justify-center border-none focus-visible:ring-2 focus-visible:ring-primary-background focus-visible:ring-offset-1 focus-visible:outline-none`,e.variant===`badge`?`h-4.5 w-8 rounded-full`:`size-6 rounded-sm`,e.mode===`fixed`?`bg-transparent`:`bg-primary-background/30 hover:bg-primary-background-hover/30`))},[i[e.mode]?(d(),f(`i`,{key:0,"aria-hidden":`true`,class:n(c(y)(i[e.mode]??``,`text-xs`,e.mode===`fixed`?`text-muted-foreground`:`text-primary-background`))},null,2)):a[e.mode]?(d(),f(`span`,S,l(a[e.mode]),1)):t(``,!0)],10,x))}}),w={class:`relative grid grid-cols-subgrid`},T=s({__name:`WidgetWithControl`,props:r({widget:{},component:{}},{modelValue:{},modelModifiers:{}}),emits:[`update:modelValue`],setup(t){let n=o(()=>e(()=>import(`./ValueControlPopover-B4ZTqZ2U.js`),__vite__mapDeps([0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42]),import.meta.url)),r=t,s=_(t,`modelValue`),l=m(r.widget.controlWidget.value);return g(l,r.widget.controlWidget.update),(e,t)=>(d(),f(`div`,w,[(d(),p(h(e.component),a(e.$attrs,{modelValue:s.value,"onUpdate:modelValue":t[1]||=e=>s.value=e,widget:e.widget}),{default:u(()=>[i(b,null,{button:u(()=>[i(C,{mode:l.value,class:`self-center`},null,8,[`mode`])]),default:u(()=>[i(c(n),{modelValue:l.value,"onUpdate:modelValue":t[0]||=e=>l.value=e},null,8,[`modelValue`])]),_:1})]),_:1},16,[`modelValue`,`widget`]))]))}});export{T as t};
//# sourceMappingURL=WidgetWithControl-CwCcGJBK.js.map