import"./rolldown-runtime-DIIn1E2Q.js";import"./vendor-primevue-_eYbXsHY.js";import"./vendor-firebase-D7u00oy9.js";import{F as e,I as t,O as n,R as r,Rt as i,S as a,Ut as o,Z as s,_t as c,et as l,j as u,rt as d,t as f}from"./vendor-vue-core-DO0afONr.js";import"./vendor-other-D7fTIduy.js";import"./useFeatureFlags-ChmiVSwD.js";import"./api-BebQfoGK.js";import"./vendor-markdown-Da9QPS2x.js";import"./colorUtil-xHrUTSza.js";import{n as p}from"./vendor-i18n-JbyM4Qz7.js";import"./i18n-dAUEhQVe.js";import"./vendor-reka-ui-D1HCh14_.js";import{t as m}from"./Button-hTbieW3T.js";import"./dialogService-Cm1GEBK8.js";import"./formatUtil-Gr6H7233.js";import"./userStore-DMlTsx5E.js";import"./useErrorHandling-DudkVSep.js";import"./extensionStore-P-YqST__.js";import{t as h}from"./_plugin-vue_export-helper-C-lmfiIY.js";import"./useExternalLink-DY6FqhTr.js";import"./vendor-tiptap-CcjHVRxb.js";import"./markdownRendererUtil-PltcX2Bi.js";import"./Popover-BhkpNQxC.js";import"./electronDownloadStore-BYrGQ7mS.js";import{t as g}from"./GlobalToast-DHYvVkn4.js";import{t as _}from"./BaseViewTemplate-DBZUwRdb.js";var v=``+new URL(`thumbnail-imMA3y7Z.png`,import.meta.url).href,y=``+new URL(`video-BvOHf4P9.mp4`,import.meta.url).href,b=``+new URL(`images/comfy-cloud-logo.svg`,import.meta.url).href,x={},S={class:`mx-auto flex h-[7%] max-h-[70px] w-5/6 items-end`},C=[`alt`];function _sfc_render(e,t){return l(),u(`div`,S,[n(`img`,{src:b,alt:e.$t(`subscription.comfyCloudLogo`),class:`h-3/4 max-h-10 w-auto`},null,8,C)])}var w=h(x,[[`render`,_sfc_render]]),T={class:`mx-auto flex h-[5%] max-h-[60px] w-5/6 items-start gap-2.5`},E={href:`https://www.comfy.org/terms-of-service`,target:`_blank`,class:`cursor-pointer text-sm text-gray-600 no-underline`},D={href:`https://www.comfy.org/privacy-policy`,target:`_blank`,class:`cursor-pointer text-sm text-gray-600 no-underline`},O={href:`https://support.comfy.org`,class:`cursor-pointer text-sm text-gray-600 no-underline`,target:`_blank`,rel:`noopener noreferrer`},k=r({__name:`CloudTemplateFooter`,setup(e){let{t}=p();return(e,r)=>(l(),u(`footer`,T,[n(`a`,E,o(i(t)(`auth.login.termsLink`)),1),n(`a`,D,o(i(t)(`auth.login.privacyLink`)),1),n(`a`,O,o(i(t)(`cloudFooter_needHelp`)),1)]))}}),A={class:`flex`},j={class:`relative hidden flex-1 overflow-hidden bg-black lg:block`},M=[`poster`],N=[`src`],P={class:`absolute inset-0 flex items-center justify-center text-center text-white`},F={class:`font-abcrom hero-title font-black uppercase italic`},I={class:`m-2 text-center text-xl text-white`},L={class:`m-0 text-center text-xl text-white`},R={class:`absolute inset-0 flex flex-col justify-end px-14 pb-[64px]`},z={class:`flex items-center justify-end`},B={class:`flex items-center gap-3`},V={class:`text-md text-white`},H=r({__name:`CloudTemplate`,setup(r){let{t:a}=p(),handleDownloadClick=()=>{window.open(`https://www.comfy.org/download`,`_blank`)};return(r,s)=>(l(),u(`div`,A,[t(_,{dark:``,class:`flex-1`},{header:c(()=>[t(w)]),footer:c(()=>[t(k)]),default:c(()=>[d(r.$slots,`default`)]),_:3}),n(`div`,j,[n(`video`,{class:`absolute inset-0 size-full object-cover`,autoplay:``,muted:``,loop:``,playsinline:``,poster:i(v)},[n(`source`,{src:i(y),type:`video/mp4`},null,8,N)],8,M),s[0]||=n(`div`,{class:`absolute inset-0 size-full bg-black/30`},null,-1),n(`div`,P,[n(`div`,null,[n(`h1`,F,o(i(a)(`cloudStart_title`)),1),n(`p`,I,o(i(a)(`cloudStart_desc`)),1),n(`p`,L,o(i(a)(`cloudStart_explain`)),1)])]),n(`div`,R,[n(`div`,z,[n(`div`,B,[n(`p`,V,o(i(a)(`cloudStart_wantToRun`)),1),t(m,{type:`button`,class:`h-10 bg-black font-bold text-white`,variant:`secondary`,onClick:handleDownloadClick},{default:c(()=>[e(o(i(a)(`cloudStart_download`)),1)]),_:1})])])])])]))}}),U=r({__name:`CloudLayoutView`,setup(e){return s(()=>{document.getElementById(`splash-loader`)?.remove()}),(e,n)=>(l(),u(a,null,[t(H,null,{default:c(()=>[t(i(f))]),_:1}),t(g)],64))}});export{U as default};
//# sourceMappingURL=CloudLayoutView-DI3qJ-FI.js.map