import"./rolldown-runtime-DIIn1E2Q.js";import{b as e,r as t}from"./vendor-primevue-_eYbXsHY.js";import{A as n,Bt as r,D as i,F as a,I as o,O as s,R as c,Rt as l,S as u,Ut as d,_t as f,et as p,j as m,kt as h}from"./vendor-vue-core-DO0afONr.js";import{n as g}from"./vendor-i18n-JbyM4Qz7.js";var _={class:`mb-2 flex items-center justify-between`},v={class:`text-base font-medium opacity-80`,for:`comfy-org-sign-up-password`},y={class:`flex flex-col gap-1`},b={key:0,class:`text-sm`},x={class:`mt-1 space-y-1`},S={class:`mb-2 text-base font-medium opacity-80`,for:`comfy-org-sign-up-confirm-password`},C={key:0,class:`text-red-500`},w=c({__name:`PasswordFields`,setup(c){let{t:w}=g(),T=h(``),E=i(()=>({length:T.value.length>=8&&T.value.length<=32,uppercase:/[A-Z]/.test(T.value),lowercase:/[a-z]/.test(T.value),number:/\d/.test(T.value),special:/[^A-Za-z0-9]/.test(T.value)}));return(i,c)=>(p(),m(u,null,[o(l(t),{name:`password`,class:`flex flex-col gap-2`},{default:f(t=>[s(`div`,_,[s(`label`,v,d(l(w)(`auth.signup.passwordLabel`)),1)]),o(l(e),{modelValue:T.value,"onUpdate:modelValue":c[0]||=e=>T.value=e,"input-id":`comfy-org-sign-up-password`,"pt:pc-input-text:root:autocomplete":`new-password`,name:`password`,feedback:!1,"toggle-mask":``,placeholder:l(w)(`auth.signup.passwordPlaceholder`),class:r([{"p-invalid":t.invalid},`h-10`]),fluid:``},null,8,[`modelValue`,`placeholder`,`class`]),s(`div`,y,[t.dirty||t.invalid?(p(),m(`small`,b,[a(d(l(w)(`validation.password.requirements`))+`: `,1),s(`ul`,x,[s(`li`,{class:r({"text-red-500":!E.value.length})},d(l(w)(`validation.password.minLength`)),3),s(`li`,{class:r({"text-red-500":!E.value.uppercase})},d(l(w)(`validation.password.uppercase`)),3),s(`li`,{class:r({"text-red-500":!E.value.lowercase})},d(l(w)(`validation.password.lowercase`)),3),s(`li`,{class:r({"text-red-500":!E.value.number})},d(l(w)(`validation.password.number`)),3),s(`li`,{class:r({"text-red-500":!E.value.special})},d(l(w)(`validation.password.special`)),3)])])):n(``,!0)])]),_:1}),o(l(t),{name:`confirmPassword`,class:`flex flex-col gap-2`},{default:f(t=>[s(`label`,S,d(l(w)(`auth.login.confirmPasswordLabel`)),1),o(l(e),{name:`confirmPassword`,"input-id":`comfy-org-sign-up-confirm-password`,"pt:pc-input-text:root:autocomplete":`new-password`,feedback:!1,"toggle-mask":``,placeholder:l(w)(`auth.login.confirmPasswordPlaceholder`),class:r([{"p-invalid":t.invalid},`h-10`]),fluid:``},null,8,[`placeholder`,`class`]),t.error?(p(),m(`small`,C,d(t.error.message),1)):n(``,!0)]),_:1})],64))}});export{w as t};
//# sourceMappingURL=PasswordFields-CZJEU0zr.js.map