import"./rolldown-runtime-DIIn1E2Q.js";import{O as e,R as t,Ut as n,b as r,et as i,j as a}from"./vendor-vue-core-DO0afONr.js";var o={class:`relative size-full overflow-hidden rounded-sm`},s={class:`flex size-full flex-col items-center justify-center gap-2 bg-modal-card-placeholder-background transition-transform duration-300 group-hover:scale-105 group-data-[selected=true]:scale-105`},c={class:`text-base-foreground`},l=[`src`],u=t({__name:`MediaAudioTop`,props:{asset:{}},setup(t){return(t,u)=>(i(),a(`div`,o,[e(`div`,s,[u[1]||=e(`i`,{class:`icon-[lucide--music] text-3xl text-base-foreground`},null,-1),e(`span`,c,n(t.$t(`assetBrowser.media.audioPlaceholder`)),1)]),e(`audio`,{controls:``,class:`absolute bottom-0 left-0 w-full p-2`,src:t.asset.src,onClick:u[0]||=r(()=>{},[`stop`])},null,8,l)]))}});export{u as default};
//# sourceMappingURL=MediaAudioTop-Dt1IFs0G.js.map