import"./rolldown-runtime-DIIn1E2Q.js";import{A as e,Bt as t,D as n,F as r,I as i,K as a,R as o,Ut as s,_t as c,et as l,j as u}from"./vendor-vue-core-DO0afONr.js";import"./vendor-other-D7fTIduy.js";import"./vendor-reka-ui-D1HCh14_.js";import{t as d}from"./Button-hTbieW3T.js";import{o as f,t as p}from"./widgetPropFilter-CM0eri-7.js";var m={class:`flex flex-col gap-1`},h=o({__name:`WidgetButton`,props:{widget:{}},setup(o){let h=o,g=[...p,`iconClass`],_=n(()=>f(h.widget.options,g)),handleClick=()=>{h.widget.callback&&h.widget.callback()};return(n,o)=>(l(),u(`div`,m,[i(d,a({class:`w-full border-0 bg-component-node-widget-background p-2 text-base-foreground`,"aria-label":n.widget.label,size:`sm`,variant:`textonly`},_.value,{onClick:handleClick}),{default:c(()=>[r(s(n.widget.label??n.widget.name)+` `,1),n.widget.options?.iconClass?(l(),u(`i`,{key:0,class:t(n.widget.options.iconClass)},null,2)):e(``,!0)]),_:1},16,[`aria-label`])]))}});export{h as default};
//# sourceMappingURL=WidgetButton-pBi8kv3H.js.map